==> apache-streampark-2.0.0-incubating-src.tar.gz: apache-streampark-2.0.0-incubating-src/streampark-flink/streampark-flink-packer/src/main/scala/org/apache/streampark/flink/packer/docker/FlinkDockerfileTemplate.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.streampark.flink.packer.docker

/**
 * Base flink docker file image template.
 *
 * @param workspacePath      Path of dockerfile workspace, it should be a directory.
 * @param flinkBaseImage     Flink base docker image name, see https://hub.docker.com/_/flink.
 * @param flinkMainJarPath   Path of flink job main jar which would copy to $FLINK_HOME/usrlib/
 * @param flinkExtraLibPaths Path of additional flink lib path which would copy to $FLINK_HOME/lib/
 */
case class FlinkDockerfileTemplate(workspacePath: String, flinkBaseImage: String, flinkMainJarPath: String, flinkExtraLibPaths: Set[String])
    extends FlinkDockerfileTemplateTrait {

  /**
   * offer content of DockerFile
   */
  override def offerDockerfileContent: String = {
    s"""FROM $flinkBaseImage
       |RUN mkdir -p $FLINK_HOME/usrlib
       |COPY $extraLibName $FLINK_HOME/lib/
       |COPY $mainJarName $FLINK_HOME/usrlib/$mainJarName
       |""".stripMargin
  }

}

==> apache-streampark-2.1.0-incubating-src.tar.gz: apache-streampark-2.1.0-incubating-src/streampark-flink/streampark-flink-packer/src/main/scala/org/apache/streampark/flink/packer/docker/FlinkDockerfileTemplate.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.streampark.flink.packer.docker

/**
 * Base flink docker file image template.
 *
 * @param workspacePath
 *   Path of dockerfile workspace, it should be a directory.
 * @param flinkBaseImage
 *   Flink base docker image name, see https://hub.docker.com/_/flink.
 * @param flinkMainJarPath
 *   Path of flink job main jar which would copy to $FLINK_HOME/usrlib/
 * @param flinkExtraLibPaths
 *   Path of additional flink lib path which would copy to $FLINK_HOME/lib/
 */
case class FlinkDockerfileTemplate(
    workspacePath: String,
    flinkBaseImage: String,
    flinkMainJarPath: String,
    flinkExtraLibPaths: Set[String])
  extends FlinkDockerfileTemplateTrait {

  /** offer content of DockerFile */
  override def offerDockerfileContent: String = {
    s"""FROM $flinkBaseImage
       |RUN mkdir -p $FLINK_HOME/usrlib
       |COPY $extraLibName $FLINK_HOME/lib/
       |COPY $mainJarName $FLINK_HOME/usrlib/$mainJarName
       |""".stripMargin
  }

}
